@@ -108,7 +108,7 @@ adaboost <- function(input_model=NA,
   }
 
   if (!identical(test, NA)) {
-    SetParamMat(p, "test", to_matrix(test))
+    SetParamMat(p, "test", to_matrix(test), TRUE)
   }
 
   if (!identical(tolerance, NA)) {
@@ -116,7 +116,7 @@ adaboost <- function(input_model=NA,
   }
 
   if (!identical(training, NA)) {
-    SetParamMat(p, "training", to_matrix(training))
+    SetParamMat(p, "training", to_matrix(training), TRUE)
   }
 
   if (!identical(weak_learner, NA)) {
