@@ -209,11 +209,11 @@ cf <- function(algorithm=NA,
   }
 
   if (!identical(test, NA)) {
-    SetParamMat(p, "test", to_matrix(test))
+    SetParamMat(p, "test", to_matrix(test), TRUE)
   }
 
   if (!identical(training, NA)) {
-    SetParamMat(p, "training", to_matrix(training))
+    SetParamMat(p, "training", to_matrix(training), TRUE)
   }
 
   if (verbose) {
