@@ -133,7 +133,7 @@ krann <- function(alpha=NA,
   }
 
   if (!identical(query, NA)) {
-    SetParamMat(p, "query", to_matrix(query))
+    SetParamMat(p, "query", to_matrix(query), TRUE)
   }
 
   if (!identical(random_basis, FALSE)) {
@@ -141,7 +141,7 @@ krann <- function(alpha=NA,
   }
 
   if (!identical(reference, NA)) {
-    SetParamMat(p, "reference", to_matrix(reference))
+    SetParamMat(p, "reference", to_matrix(reference), TRUE)
   }
 
   if (!identical(sample_at_leaves, FALSE)) {
