@@ -69,7 +69,7 @@ pca <- function(input,
   inputModels <- vector()
 
   # Process each input argument before calling the binding.
-  SetParamMat(p, "input", to_matrix(input))
+  SetParamMat(p, "input", to_matrix(input), TRUE)
 
   if (!identical(decomposition_method, NA)) {
     SetParamString(p, "decomposition_method", decomposition_method)
