@@ -69,7 +69,7 @@ radical <- function(input,
   inputModels <- vector()
 
   # Process each input argument before calling the binding.
-  SetParamMat(p, "input", to_matrix(input))
+  SetParamMat(p, "input", to_matrix(input), TRUE)
 
   if (!identical(angles, NA)) {
     SetParamInt(p, "angles", angles)
